==> mysql-workbench_5.2.40+dfsg.orig.tar.xz: mysql-workbench-5.2.40/library/forms/stub/stub_popup.h <==
/* 
 * Copyright (c) 2008, 2011, Oracle and/or its affiliates. All rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; version 2 of the
 * License.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
#ifndef _STUB_POPUP_H_
#define _STUB_POPUP_H_

#include "stub_view.h"

namespace mforms {
namespace stub {

class PopupImpl : public ViewImpl
{
 protected:
  PopupImpl(::mforms::WebBrowser *self)
    : ViewImpl(self)
  {
  }

  static bool __stdcall create(Popup *, PopupStyle)
  {
    return true;
  }

  static void __stdcall set_needs_repaint(Popup *)
  {
  }

  static void __stdcall set_size(Popup *, int, int)
  {
  }

  static int __stdcall show(Popup *, int, int)
  {
    return 0;
  }

  static MySQL::Geometry::Rect __stdcall get_content_rect(Popup *)
  {
    MySQL::Geometry::Rect ret_val;

    return ret_val;
  }

  static void __stdcall set_modal_result(Popup *, int result)
  {
  }




public:
  static void init()
  {
    ::mforms::ControlFactory *f = ::mforms::ControlFactory::get_instance();

    f->_popup_impl.create = &PopupImpl::create;
    f->_popup_impl.get_content_rect = &PopupImpl::get_content_rect;
    f->_popup_impl.set_modal_result = &PopupImpl::set_modal_result;
    f->_popup_impl.set_needs_repaint = &PopupImpl::set_needs_repaint;
    f->_popup_impl.set_size = &PopupImpl::set_size;
    f->_popup_impl.show = &PopupImpl::show;
  }
};

}
}

#endif

==> mysql-workbench_6.0.8+dfsg.orig.tar.xz: mysql-workbench-6.0.8/library/forms/stub/stub_popup.h <==
/* 
 * Copyright (c) 2008, 2012, Oracle and/or its affiliates. All rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; version 2 of the
 * License.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
#ifndef _STUB_POPUP_H_
#define _STUB_POPUP_H_

#include "stub_view.h"

namespace mforms {
namespace stub {

class PopupImpl : public ViewImpl
{
 protected:
  PopupImpl(::mforms::WebBrowser *self)
    : ViewImpl(self)
  {
  }

  static bool __stdcall create(Popup *, PopupStyle)
  {
    return true;
  }

  static void __stdcall set_needs_repaint(Popup *)
  {
  }

  static void __stdcall set_size(Popup *, int, int)
  {
  }

  static int __stdcall show(Popup *, int, int)
  {
    return 0;
  }

  static base::Rect __stdcall get_content_rect(Popup *)
  {
    base::Rect ret_val;

    return ret_val;
  }

  static void __stdcall set_modal_result(Popup *, int result)
  {
  }




public:
  static void init()
  {
    ::mforms::ControlFactory *f = ::mforms::ControlFactory::get_instance();

    f->_popup_impl.create = &PopupImpl::create;
    f->_popup_impl.get_content_rect = &PopupImpl::get_content_rect;
    f->_popup_impl.set_modal_result = &PopupImpl::set_modal_result;
    f->_popup_impl.set_needs_repaint = &PopupImpl::set_needs_repaint;
    f->_popup_impl.set_size = &PopupImpl::set_size;
    f->_popup_impl.show = &PopupImpl::show;
  }
};

}
}

#endif
